# AUTOGENERATED! DO NOT EDIT! File to edit: dev/00_core.ipynb (unless otherwise specified).

__all__ = ['med_csv', 'med_show']

# Cell
def med_csv():
    print("TODO")

# Cell
def med_show(df,num_to_show=5,transpose=True):
    #df.head(2).T
    print(f'{num_to_show}_TODO')


# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"med_csv": "00_core.ipynb",
         "med_show": "00_core.ipynb"}

modules = ["core.py"]

git_url = "https://github.com/Daniel-R_Armstrong/med2nlp/tree/master/"


def custom_doc_links(name): return None
